# detoxio.ai SDK

## Installation

```bash
python3 -m pip install detoxio \
    detoxio-ai-api-protocolbuffers-python detoxio_api_grpc_python \
    --upgrade --extra-index-url https://buf.build/gen/python
```

> **Note:** We need to install additional packages because as per PEP-440, we
> cannot have a package with direct dependencies outside the public index

## Usage

* https://docs.detoxio.ai/

